@@ -82,7 +82,6 @@ class Config(object):
             raise e
 
 
-
 config = Config()
 
 
@@ -168,9 +167,21 @@ class Log(object):
         raise Exception(message)
 
 
-
 log = Log()
 
+
+def catch_error_log(func):
+    def try_catch(*args, **kwargs):
+        try:
+            return func(*args, **kwargs)
+        except Exception as e:
+            print("%s: %s" % (func.__name__, e))
+            log.exception("%s: %s" % (func.__name__, e))
+            return None
+
+    return try_catch
+
+
 if __name__ == '__main__':
     host = config('db_stock', 'host', '12')
     print(host)
