@@ -44,10 +44,9 @@ def get_es_client(label='', host='', user='', password=''):
 
 
 class EsOperate(object):
-    def __init__(self, conn, index, doc_type='doc', doc_model=Document, size=2000):
+    def __init__(self, conn, index, doc_model=Document, size=2000):
         self.conn = conn
         self.index = index
-        self.doc_type = doc_type
         self.doc_model = doc_model
         self.size = size
 
@@ -65,8 +64,8 @@ class EsOperate(object):
         es_news = self.doc_model.get(id=publish_id)
         es_news.delete()
 
-    def delete_by_id(self, id):
-        self.conn.delete(index=self.index, doc_type=self.doc_type, id=id, ignore=[400, 404])
+    def delete_by_id(self, id, **kwargs):
+        self.conn.delete(index=self.index, id=id, ignore=[400, 404], **kwargs)
 
     def set_alias(self, other_name):
         self.conn.indices.put_alias(index=self.index, name=other_name)
@@ -74,8 +73,8 @@ class EsOperate(object):
     def delete_alias(self, other_name):
         self.conn.indices.delete_alias(index=self.index, name=other_name, ignore=[400, 404])
 
-    def add_one_data(self, body, id=None):
-        self.conn.index(index=self.index, doc_type=self.doc_type, body=body, id=id)
+    def add_one_data(self, body, id=None, **kwargs):
+        self.conn.index(index=self.index, body=body, id=id, **kwargs)
 
     def __query_iterator(self, query):
         total = query['hits']['total']  # es查询出的结果总量
@@ -103,62 +102,51 @@ class EsOperate(object):
                 query_list = query['hits']['hits']
             yield query_list
 
-    def get_query_iterator(self, body):
-        query = self.conn.search(index=self.index, doc_type=self.doc_type, body=body, scroll='5m', size=self.size, ignore=[400, 404])
+    def get_query_iterator(self, body, **kwargs):
+        query = self.conn.search(index=self.index, body=body, scroll='5m', size=self.size, ignore=[400, 404], **kwargs)
         return self.__query_iterator(query)
 
-    def get_query_iterator_origin(self, body):
-        query = self.conn.search(index=self.index, doc_type=self.doc_type, body=body, scroll='5m', size=self.size, ignore=[400, 404])
+    def get_query_iterator_origin(self, body, **kwargs):
+        query = self.conn.search(index=self.index, body=body, scroll='5m', size=self.size, ignore=[400, 404], **kwargs)
         return self.__query_iterator_origin(query)
 
-    def es_query(self, body):
-        _data = self.conn.search(index=self.index, doc_type=self.doc_type, body=body, ignore=[400, 404], size=self.size)
+    def es_query(self, body, **kwargs):
+        _data = self.conn.search(index=self.index, body=body, ignore=[400, 404], size=self.size, **kwargs)
         return _data
 
-    def get_one_data(self, id):
-        _data = self.conn.get(index=self.index, doc_type=self.doc_type, id=id, ignore=[400, 404])
+    def get_one_data(self, id, **kwargs):
+        _data = self.conn.get(index=self.index, id=id, ignore=[400, 404], **kwargs)
         return _data
 
-    def update_one_data(self, id, body=None):
-        self.conn.update(index=self.index, doc_type=self.doc_type, id=id, body=body)
+    def update_one_data(self, id, body=None, **kwargs):
+        self.conn.update(index=self.index, id=id, body=body, **kwargs)
 
     # 查询field="python"或"android"的所有数据
     # term_name = {"field": ["python", "android"]}
-    def terms_query(self, term_name):
+    def terms_query(self, term_name, **kwargs):
         _body = {'query': {'term': term_name}, 'size': 10, 'from': 0}
-        _data = self.conn.search(index=self.index, doc_type=self.doc_type, body=_body)
+        _data = self.conn.search(index=self.index, body=_body, **kwargs)
         return _data
 
     # term_name = {"field": ["python", "android"]}field包含python关键字的数据
-    def match_query(self, term_name):
+    def match_query(self, term_name, **kwargs):
         # match:匹配name包含python关键字的数据
         _body = {'query': {'match': term_name}, 'size': 10}
-        _data = self.conn.search(index=self.index, doc_type=self.doc_type, body=_body)
+        _data = self.conn.search(index=self.index, body=_body, **kwargs)
         return _data
 
     # 多个字段其一含有某个字符
     # term_name = {"query": "深圳", "fields": ["name", "addr"]}
-    def multi_match(self, term_name):
+    def multi_match(self, term_name, **kwargs):
         _body = {'query': {'multi_match': term_name}, 'size': 10}
-        _data = self.conn.search(index=self.index, doc_type=self.doc_type, body=_body)
+        _data = self.conn.search(index=self.index, body=_body, **kwargs)
         return _data
 
-    def bulk_to_es(self, bulk_list):
+    def bulk_to_es(self, bulk_list, **kwargs):
         _length = len(bulk_list)
         if _length > 100:
             for i in range(0, _length, 100):
-                bulk(self.conn, bulk_list[i: i + 100], index=self.index, doc_type=self.doc_type)
+                bulk(self.conn, bulk_list[i: i + 100], index=self.index, **kwargs)
         else:
-            bulk(self.conn, bulk_list, index=self.index, doc_type=self.doc_type)
+            bulk(self.conn, bulk_list, index=self.index, **kwargs)
 
-
-def test():
-    es_client = get_es_client(label='es')
-    indexer = EsOperate(es_client, 'other_name')
-    for data in indexer.get_all_data_iterator():
-        print(data)
-        break
-
-
-if __name__ == '__main__':
-    test()
