@@ -5,7 +5,7 @@ from elasticsearch_dsl import Document, Integer, Keyword
 from .config_log import config
 from .config_log import log
 from .utils import make_timestamp
-from elasticsearch_dsl.query import Q
+from elasticsearch_dsl.query import Q, Match
 
 __es_clients = {}
 __es_entitys = {}
@@ -300,3 +300,45 @@ class DocumentBase(Document):
     class Index:
         name = ''
         label = ''
+
+
+
+class GetResByEs(object):
+    # ['总论', '自然', '自然辩证法', '自然辩证法总论']
+    @classmethod
+    def str_list_element_drop_contain_sorted(cls, str_list: list):
+        str_list = [obj.lower() for obj in str_list]
+        if len(str_list) < 2:
+            return str_list
+        str_list = sorted(str_list, key=lambda e: len(e), reverse=True)
+        res_list = []
+        for i in range(1, len(str_list) + 1):
+            exist = False
+            for j in range(len(str_list) - i):
+                if str_list[-1 * i] in str_list[j]:
+                    exist = True
+                    break
+            if not exist:
+                res_list.insert(0, str_list[-1 * i])
+        return res_list
+
+    @classmethod
+    def getResOfNameInQuery(cls, text, es_model, key='name', limit=40):
+        es_search = BaseSearcher(es_model.Index.using, doc_model=es_model)
+        total, query_list = es_search.search_by_multi_bool(should=[Match(name=text)], limit=limit)
+        query_list = [r['_source'] for r in query_list]
+        name_dict = dict()
+        name_list = []
+        for x in query_list:
+            if x.get(key) and x.get(key).lower() in text.lower():
+                name_list.append(x[key])
+                name_dict[x[key]] = x
+        return {'name_list': name_list, 'name_map': name_dict}
+
+    @classmethod
+    def getNer(cls, text, es_model, limit=40):
+        res_map = cls.getResOfNameInQuery(text, es_model, limit=limit)
+        origin_ner = res_map['name_list']
+        import copy
+        merge_ner = cls.str_list_element_drop_contain_sorted(copy.deepcopy(origin_ner))
+        return {'origin_ner': origin_ner, 'merge_ner': merge_ner}
\ No newline at end of file
