@@ -21,18 +21,8 @@ class TimeEtl(object):
         return datetime.datetime.now()
 
     @classmethod
-    def time_str(cls, _now):
-        _str_now = _now.strftime("%Y-%m-%d %H:%M:%S")
-        return _str_now
-
-    @classmethod
-    def time_date(cls, _now):
-        _str_now = _now.strftime("%Y-%m-%d")
-        return _str_now
-
-    @classmethod
-    def time_clock(cls, _now):
-        _str_now = _now.strftime("%H:%M:%S")
+    def time_str(cls, _now, format='%Y-%m-%d %H:%M:%S'):
+        _str_now = _now.strftime(format)
         return _str_now
 
     @classmethod
@@ -41,8 +31,8 @@ class TimeEtl(object):
         return int(un_time)
 
     @classmethod
-    def str_time(cls, _str):
-        _time = datetime.datetime.strptime(_str, "%Y-%m-%d %H:%M:%S")
+    def str_time(cls, _str, format='%Y-%m-%d %H:%M:%S'):
+        _time = datetime.datetime.strptime(_str, format)
         return _time
 
     @classmethod
@@ -52,32 +42,27 @@ class TimeEtl(object):
         return _time_stamp
 
     @classmethod
-    def date_time(cls, _str):
-        _time = datetime.datetime.strptime(_str, "%Y-%m-%d")
-        return _time
-
-    @classmethod
-    def stamp_time(cls, _stamp):
-        _dt = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(_stamp))
+    def stamp_time(cls, _stamp, format="%Y-%m-%d %H:%M:%S"):
+        _dt = time.strftime(format, time.localtime(_stamp))
         return _dt
 
     @classmethod
-    def before_day(cls, _now, _day):
-        _time = (_now - datetime.timedelta(days=_day)).strftime("%Y-%m-%d")
+    def before_day(cls, _now, _day, format="%Y-%m-%d %H:%M:%S"):
+        _time = (_now - datetime.timedelta(days=_day)).strftime(format)
         return _time
 
     @classmethod
-    def after_day(cls, _now, _day):
-        _time = (_now + datetime.timedelta(days=_day)).strftime("%Y-%m-%d")
+    def after_day(cls, _now, _day, format="%Y-%m-%d %H:%M:%S"):
+        _time = (_now + datetime.timedelta(days=_day)).strftime(format)
         return _time
 
 
 etl_time = TimeEtl()
 
 if __name__ == '__main__':
-    _now = datetime.datetime.now()
-    _str_time = TimeEtl.time_stamp(_now)
+    _now = TimeEtl.ge_now()
+    # _str_time = TimeEtl.time_stamp(_now)
     # print(_str_time)
     #
-    _time = TimeEtl.stamp_time(_str_time)
+    _time = TimeEtl.before_day(_now, 5)
     print(_time)
