@@ -28,10 +28,31 @@ _ProcessNum = 3
 _Thread = 4
 
 
+##datetime.datetime is not JSON serializable 报错问题解决
+class CJsonEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, datetime.datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+            # return obj.strftime('%H:%M:%S')
+        elif isinstance(obj, date):
+            return obj.strftime("%Y-%m-%d")
+        elif isinstance(obj, numpy.integer):
+            return int(obj)
+        elif isinstance(obj, numpy.floating):
+            return float(obj)
+        elif isinstance(obj, numpy.ndarray):
+            return obj.tolist()
+        elif isinstance(obj, bytes):
+            return str(obj)
+        return json.JSONEncoder.default(self, obj)
+
+
 class DataTypeToStr(object):
     @classmethod
     def data_type_to_str(cls, obj):
-        if isinstance(obj, datetime.datetime):
+        if obj != obj:
+            return None
+        elif isinstance(obj, datetime.datetime):
             return obj.strftime('%Y-%m-%d %H:%M:%S')
         elif isinstance(obj, numpy.datetime64):
             return pd.to_datetime(str(obj)).strftime('%Y-%m-%d %H:%M:%S')
@@ -41,11 +62,11 @@ class DataTypeToStr(object):
                 or isinstance(obj, float) or isinstance(obj, bytes):
             return str(obj)
         elif isinstance(obj, numpy.ndarray):
-            return json.dumps(obj.tolist(), ensure_ascii=False)
+            return json.dumps(obj.tolist(), ensure_ascii=False, cls=CJsonEncoder)
         elif isinstance(obj, list):
-            return json.dumps(obj, ensure_ascii=False)
+            return json.dumps(obj, ensure_ascii=False, cls=CJsonEncoder)
         elif isinstance(obj, dict):
-            return json.dumps(obj, ensure_ascii=False)
+            return json.dumps(obj, ensure_ascii=False, cls=CJsonEncoder)
         else:
             return obj
 
@@ -410,8 +431,13 @@ class UpdateTable(SqlDateOp):
         return _update_dict
 
 
+class SqlDataOp(SqlDateOp):
+    def name_true(self):
+        pass
+
+
 if __name__ == '__main__':
-    _db = SqlDateOp('160', 'xw_test', single_entity=True)
+    _db = SqlDateOp(label='160', db='xw_test', single_entity=True)
     # _db_1 = SqlDateOp('160', 'xw_test', single_entity=True)
     # print(id(_db))
     # print(id(_db_1))
